@@ -235,7 +235,7 @@ def preprocessing_preleads(df,industry_dictionary,state_dictionary,mx_bv_diction
 
     logging.info( f"NA after ONH:" )
     logging.info( f"{df_preleads_clean.columns}" )
-    _, df_preleads_clean = sample.align(df_preleads_clean,join='left',axis=1)
+    _, df_preleads_clean = sample.align(df_preleads_clean,join='left',axis=1,fill_value=0)
     
     logging.info( f"NA after aligning:" )
     logging.info( f"{df_preleads_clean.columns}" )
